@@ -9,6 +9,6 @@ test_that("make_search_url matches number of papers from_year to_year", {
                               from_year = 1990,
                               to_year   = 2000,
                               how = "all")
-    expect_equal(get_papers_count(my_url), expected, tolerance = expected*1.1)
+    expect_gte(get_papers_count(my_url), expected)
 
 })
